<?php return array(
    'root' => array(
        'name' => 'icinga/icinga-php-library',
        'pretty_version' => 'dev-main',
        'version' => 'dev-main',
        'reference' => 'ca92d8e26e6d284df2e48433938c72186136bed1',
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        'brick/math' => array(
            'pretty_version' => '0.9.3',
            'version' => '0.9.3.0',
            'reference' => 'ca57d18f028f84f777b2168cd1911b0dee2343ae',
            'type' => 'library',
            'install_path' => __DIR__ . '/../brick/math',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'cweagans/composer-patches' => array(
            'pretty_version' => '1.7.3',
            'version' => '1.7.3.0',
            'reference' => 'e190d4466fe2b103a55467dfa83fc2fecfcaf2db',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../cweagans/composer-patches',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/collections' => array(
            'pretty_version' => '1.8.0',
            'version' => '1.8.0.0',
            'reference' => '2b44dd4cbca8b5744327de78bafef5945c7e7b5e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/collections',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/deprecations' => array(
            'pretty_version' => '1.1.3',
            'version' => '1.1.3.0',
            'reference' => 'dfbaa3c2d2e9a9df1118213f3b8b0c597bb99fab',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/deprecations',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dragonmantank/cron-expression' => array(
            'pretty_version' => 'v3.3.3',
            'version' => '3.3.3.0',
            'reference' => 'adfb1f505deb6384dc8b39804c5065dd3c8c8c0a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dragonmantank/cron-expression',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'evenement/evenement' => array(
            'pretty_version' => 'v3.0.2',
            'version' => '3.0.2.0',
            'reference' => '0a16b0d71ab13284339abb99d9d2bd813640efbc',
            'type' => 'library',
            'install_path' => __DIR__ . '/../evenement/evenement',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fortawesome/font-awesome' => array(
            'pretty_version' => '6.6.0',
            'version' => '6.6.0.0',
            'reference' => '37eff7fa00de26db41183a3ad8ed0e9119fbc44b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fortawesome/font-awesome',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/psr7' => array(
            'pretty_version' => '2.7.0',
            'version' => '2.7.0.0',
            'reference' => 'a70f5c95fb43bc83f07c9c948baa0dc1829bf201',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'icinga/icinga-php-library' => array(
            'pretty_version' => 'dev-main',
            'version' => 'dev-main',
            'reference' => 'ca92d8e26e6d284df2e48433938c72186136bed1',
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/html' => array(
            'pretty_version' => 'v0.8.1',
            'version' => '0.8.1.0',
            'reference' => '07f2fea6c1ddf032d17dd327fc3c573b73e45ef2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/html',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/i18n' => array(
            'pretty_version' => 'v0.2.2',
            'version' => '0.2.2.0',
            'reference' => 'a2b6109c5a93f86ce46d5dc351dbe75e8502cf8c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/i18n',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/orm' => array(
            'pretty_version' => 'v0.6.1',
            'version' => '0.6.1.0',
            'reference' => 'd210c4793f6b3d78d0da3eaf0e0d1eb14167701c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/orm',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/scheduler' => array(
            'pretty_version' => 'v0.1.2',
            'version' => '0.1.2.0',
            'reference' => '6119afdea07b1390bd728e350e0d80b26ec8d6ba',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/scheduler',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/sql' => array(
            'pretty_version' => 'v0.7.1',
            'version' => '0.7.1.0',
            'reference' => 'e80f1b712c4b96099b0bf9096e6efe317a165e3b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/sql',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/stdlib' => array(
            'pretty_version' => 'v0.14.0',
            'version' => '0.14.0.0',
            'reference' => 'bf5fc8f40b86bd90337db6f3be389be2a93fa64a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/stdlib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/validator' => array(
            'pretty_version' => 'v0.5.0',
            'version' => '0.5.0.0',
            'reference' => 'a601fae0ed330e63cea50e4a2a6659ca1ad97bde',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/validator',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/web' => array(
            'pretty_version' => 'v0.10.1',
            'version' => '0.10.1.0',
            'reference' => 'f4a7411791527935c426266f0aca0dba38f02780',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/web',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'mtdowling/cron-expression' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '^1.0',
            ),
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'reference' => '2b4765fddfe3b508ac62f829e852b1501d3f6e8a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-message' => array(
            'pretty_version' => '1.1',
            'version' => '1.1.0.0',
            'reference' => 'cb6ce4845ce34a8ad9e68117c10ee90a29919eba',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/log' => array(
            'pretty_version' => '1.1.4',
            'version' => '1.1.4.0',
            'reference' => 'd49695b909c3b7628b6289db5479a1c204601f11',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ralouphie/getallheaders' => array(
            'pretty_version' => '3.0.3',
            'version' => '3.0.3.0',
            'reference' => '120b605dfeb996808c31b6477290a714d356e822',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ralouphie/getallheaders',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ramsey/collection' => array(
            'pretty_version' => '1.1.4',
            'version' => '1.1.4.0',
            'reference' => 'ab2237657ad99667a5143e32ba2683c8029563d4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ramsey/collection',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ramsey/uuid' => array(
            'pretty_version' => '4.2.3',
            'version' => '4.2.3.0',
            'reference' => 'fc9bb7fb5388691fd7373cd44dcb4d63bbcf24df',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ramsey/uuid',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/event-loop' => array(
            'pretty_version' => 'v1.5.0',
            'version' => '1.5.0.0',
            'reference' => 'bbe0bd8c51ffc05ee43f1729087ed3bdf7d53354',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/event-loop',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/promise' => array(
            'pretty_version' => 'v2.11.0',
            'version' => '2.11.0.0',
            'reference' => '1a8460931ea36dc5c76838fec5734d55c88c6831',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/promise',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'rhumsaa/uuid' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '4.2.3',
            ),
        ),
        'simshaun/recurr' => array(
            'pretty_version' => 'v5.0.2',
            'version' => '5.0.2.0',
            'reference' => '1aff62e6e0ee875b3f2487352542605123ee9172',
            'type' => 'library',
            'install_path' => __DIR__ . '/../simshaun/recurr',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-ctype' => array(
            'pretty_version' => 'v1.30.0',
            'version' => '1.30.0.0',
            'reference' => '0424dff1c58f028c451efff2045f5d92410bd540',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-ctype',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php80' => array(
            'pretty_version' => 'v1.30.0',
            'version' => '1.30.0.0',
            'reference' => '77fa7995ac1b21ab60769b7323d600a991a90433',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php80',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'webmozart/assert' => array(
            'pretty_version' => '1.11.0',
            'version' => '1.11.0.0',
            'reference' => '11cb2199493b2f8a3b53e7f19068fc6aac760991',
            'type' => 'library',
            'install_path' => __DIR__ . '/../webmozart/assert',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'wikimedia/less.php' => array(
            'pretty_version' => 'v3.2.1',
            'version' => '3.2.1.0',
            'reference' => '0d5b30ba792bdbf8991a646fc9c30561b38a5559',
            'type' => 'library',
            'install_path' => __DIR__ . '/../wikimedia/less.php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
